bayespy.inference.vmp.transformations.RotateGaussianMarkovChain.get_bound_terms
===============================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianMarkovChain.get_bound_terms